@@ -2,6 +2,8 @@
 Extension methods on top of a temporary table.
 
 """
+import warnings
+
 from sqlalchemy.dialects.postgresql import insert
 
 from microcosm_postgres.context import SessionContext
@@ -34,6 +36,18 @@ def insert_many(self, items):
 
 
 def upsert_into(self, table):
+    """
+    Deprecated. Use `upsert_into_on_conflict_do_nothing` instead
+
+    """
+    warnings.warn(
+        "`upsert_into` is deprecated. Please use `upsert_into_on_conflict_do_nothing`",
+        DeprecationWarning,
+    )
+    return self.upsert_into_on_conflict_do_nothing(table)
+
+
+def upsert_into_on_conflict_do_nothing(self, table):
     """
     Upsert from a temporarty table into another table.
 
@@ -46,6 +60,17 @@ def upsert_into(self, table):
     ).rowcount
 
 
+def upsert_into_on_conflict_do_update(self, table, **on_conflict_kwargs):
+    return SessionContext.session.execute(
+        insert(table).from_select(
+            self.c,
+            self,
+        ).on_conflict_do_update(
+            **on_conflict_kwargs,
+        ),
+    ).rowcount
+
+
 def select_from(self, table):
     return SessionContext.session.query(
         table
